==> jc-1.4.0.tar.gz: java/awt/AWTError.h <==
// public class java.awt.AWTError

// class file dependencies
// @dep_class 87601feb47f0bd20 java_awt_AWTError
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_java_awt_AWTError_H_
#define _JC_java_awt_AWTError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_AWTError$sub_refs	_jc_java_awt_AWTError$sub_refs;
typedef struct _jc_java_awt_AWTError$sub_nonrefs	_jc_java_awt_AWTError$sub_nonrefs;
typedef struct _jc_java_awt_AWTError$refs	_jc_java_awt_AWTError$refs;
typedef struct _jc_java_awt_AWTError$nonrefs	_jc_java_awt_AWTError$nonrefs;
typedef struct _jc_java_awt_AWTError$object	_jc_java_awt_AWTError$object;

typedef struct _jc_java_awt_AWTError$fields_struct	_jc_java_awt_AWTError$fields_struct;
typedef const struct _jc_java_awt_AWTError$vmethods	_jc_java_awt_AWTError$vmethods;
typedef const struct _jc_java_awt_AWTError$vtable	_jc_java_awt_AWTError$vtable;
typedef const struct _jc_java_awt_AWTError$vtype	_jc_java_awt_AWTError$vtype;

// Class fields structure
struct _jc_java_awt_AWTError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_AWTError$fields_struct _jc_java_awt_AWTError$class_fields;

// Constructors
extern void _jc_java_awt_AWTError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_AWTError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_awt_AWTError$vmethods {
};

// Vtable
struct _jc_java_awt_AWTError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_awt_AWTError$vmethods	java_awt_AWTError;
};

// Vtype
struct _jc_java_awt_AWTError$vtype {
	_jc_type			type;
	_jc_java_awt_AWTError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AWTError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_AWTError$refs {
    _jc_java_awt_AWTError$sub_refs	java_awt_AWTError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AWTError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_AWTError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_awt_AWTError$sub_nonrefs	java_awt_AWTError;
};

// Object instance structure
struct _jc_java_awt_AWTError$object {
	_jc_java_awt_AWTError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AWTError$vtype	*vtype;
	_jc_java_awt_AWTError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AWTError$vtype _jc_java_awt_AWTError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AWTError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AWTError$class_object;

#endif	/* _JC_java_awt_AWTError_H_ */

==> jc-1.4.6.tar.gz: java/awt/AWTError.h <==
// public class java.awt.AWTError

// class file dependencies
// @dep_class 87601feb47f0bd20 java_awt_AWTError
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_java_awt_AWTError_H_
#define _JC_java_awt_AWTError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_AWTError$sub_refs	_jc_java_awt_AWTError$sub_refs;
typedef struct _jc_java_awt_AWTError$sub_nonrefs	_jc_java_awt_AWTError$sub_nonrefs;
typedef struct _jc_java_awt_AWTError$refs	_jc_java_awt_AWTError$refs;
typedef struct _jc_java_awt_AWTError$nonrefs	_jc_java_awt_AWTError$nonrefs;
typedef struct _jc_java_awt_AWTError$object	_jc_java_awt_AWTError$object;

typedef struct _jc_java_awt_AWTError$fields_struct	_jc_java_awt_AWTError$fields_struct;
typedef const struct _jc_java_awt_AWTError$vmethods	_jc_java_awt_AWTError$vmethods;
typedef const struct _jc_java_awt_AWTError$vtable	_jc_java_awt_AWTError$vtable;
typedef const struct _jc_java_awt_AWTError$vtype	_jc_java_awt_AWTError$vtype;

// Class fields structure
struct _jc_java_awt_AWTError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_AWTError$fields_struct _jc_java_awt_AWTError$class_fields;

// Constructors
extern void _jc_java_awt_AWTError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_AWTError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_AWTError$vmethods {
};

// Vtable
struct _jc_java_awt_AWTError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_awt_AWTError$vmethods	java_awt_AWTError;
};

// Vtype
struct _jc_java_awt_AWTError$vtype {
	_jc_type			type;
	_jc_java_awt_AWTError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AWTError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_AWTError$refs {
    _jc_java_awt_AWTError$sub_refs	java_awt_AWTError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AWTError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_AWTError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_awt_AWTError$sub_nonrefs	java_awt_AWTError;
};

// Object instance structure
struct _jc_java_awt_AWTError$object {
	_jc_java_awt_AWTError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AWTError$vtype	*vtype;
	_jc_java_awt_AWTError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AWTError$vtype _jc_java_awt_AWTError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AWTError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AWTError$class_object;

#endif	/* _JC_java_awt_AWTError_H_ */
